@@ -37,9 +37,9 @@ COMMON_METRIC_DICT: MetricFuncDict = {
     "Incurred Loss Ratio": lambda cell: 100
     * cell["incurred_loss"]
     / cell["earned_premium"],
-    "Paid Loss": lambda cell: cell["paid_loss"] / 1e6,
-    "Reported Loss": lambda cell: cell["reported_loss"] / 1e6,
-    "Incurred Loss": lambda cell: cell["incurred_loss"] / 1e6,
+    "Paid Loss": lambda cell: cell["paid_loss"],
+    "Reported Loss": lambda cell: cell["reported_loss"],
+    "Incurred Loss": lambda cell: cell["incurred_loss"],
     "Paid ATA": lambda cell, prev_cell: cell["paid_loss"] / prev_cell["paid_loss"],
     "Reported ATA": lambda cell, prev_cell: cell["reported_loss"]
     / prev_cell["reported_loss"],
@@ -90,6 +90,7 @@ def bermuda_plot_theme() -> alt.theme.ThemeConfig:
             },
             "mark": {"color": "black"},
             "title": {"anchor": "start", "offset": 20},
+            "axis": {"labelOverlap": True},
             "legend": {
                 "orient": "right",
                 "titleAnchor": "start",
@@ -242,7 +243,7 @@ def _plot_right_edge(
             ).title("Loss Ratio %"),
             color=alt.Color("Field:N"),
         )
-    )
+    ).interactive()
 
     points = (
         alt.Chart(loss_data)
@@ -376,6 +377,7 @@ def _plot_data_completeness(
 def plot_heatmap(
     triangle: Triangle,
     metric_spec: MetricFuncSpec = ["Paid Loss Ratio"],
+    show_values: bool = True,
     width: int = 400,
     height: int = 200,
     ncols: int | None = None,
@@ -400,6 +402,7 @@ def plot_heatmap(
             height=height,
             mark_scaler=max_cols,
             ncols=max_cols,
+            show_values=show_values,
         )
         .resolve_scale(color="independent")
         .resolve_legend(color="independent")
@@ -411,6 +414,7 @@ def _plot_heatmap(
     triangle: Triangle,
     metric: MetricFunc,
     name: str,
+    show_values: bool,
     title: alt.Title,
     mark_scaler: int,
 ) -> alt.Chart:
@@ -439,7 +443,7 @@ def _plot_heatmap(
         .encode(
             color=alt.when(selection)
             .then(
-                alt.Color("metric:Q", scale=alt.Scale(range=MANAGUA_VALS)).title(name)
+                alt.Color("metric:Q", scale=alt.Scale(scheme="blueorange")).title(name)
             )
             .otherwise(
                 alt.value("gray"),
@@ -459,13 +463,15 @@ def _plot_heatmap(
         .add_params(selection)
     )
 
-    text = base.mark_text(
-        fontSize=BASE_AXIS_TITLE_FONT_SIZE
-        * np.exp(-FONT_SIZE_DECAY_FACTOR * mark_scaler),
-        font="sans-serif",
-    ).encode(text=alt.Text("metric:Q", format=",.1f"))
+    if show_values:
+        text = base.mark_text(
+            fontSize=BASE_AXIS_TITLE_FONT_SIZE
+            * np.exp(-FONT_SIZE_DECAY_FACTOR * mark_scaler),
+            font="monospace",
+        ).encode(text=alt.Text("metric:Q", format=",.1f"))
 
-    return heatmap + text
+        return heatmap + text
+    return heatmap
 
 
 def plot_atas(
@@ -636,7 +642,7 @@ def _plot_growth_curve(
 
     color = (
         alt.Color("yearmonth(period_start):Q")
-        .scale(range=MANAGUA_VALS)
+        .scale(scheme="blueorange")
         .legend(title="Period Start")
     )
     color_none = color.legend(None)
@@ -651,10 +657,10 @@ def _plot_growth_curve(
     )
 
     base = alt.Chart(metric_data, title=title).encode(
-        x=alt.X("dev_lag:Q", axis=alt.Axis(grid=True, labelAngle=0)).title(
+        x=alt.X("dev_lag:Q", axis=alt.Axis(grid=True, labelAngle=0), scale=alt.Scale(padding=5)).title(
             "Dev Lag (months)"
         ),
-        y=alt.X("metric:Q").title(name),
+        y=alt.Y("metric:Q", axis=alt.Axis(labelExpr=alt.expr.if_(alt.datum.value > 1e5, alt.datum.value / 1e6 + 'M', alt.datum.value))).title(name),
         tooltip=[
             alt.Tooltip("period_start:T", title="Period Start"),
             alt.Tooltip("period_end:T", title="Period End"),
@@ -788,7 +794,7 @@ def _plot_sunset(
     )
 
     color = (
-        alt.Color("dev_lag:Q").scale(range=MANAGUA_VALS).legend(title="Development Lag")
+        alt.Color("dev_lag:Q").scale(scheme="blueorange").legend(title="Development Lag")
     )
     color_none = color.legend(None)
 
@@ -943,7 +949,7 @@ def _plot_mountain(
         )
 
     color = (
-        alt.Color("dev_lag:Q").scale(range=MANAGUA_VALS).legend(title="Development Lag")
+        alt.Color("dev_lag:Q").scale(scheme="blueorange").legend(title="Development Lag")
     )
     color_none = color.legend(None)
 
@@ -964,7 +970,7 @@ def _plot_mountain(
         x=alt.X(
             "yearmonth(period_start):O", axis=alt.Axis(grid=True, labelAngle=0)
         ).title("Period Start"),
-        y=alt.X("metric:Q").title(name),
+        y=alt.Y("metric:Q", axis=alt.Axis(labelExpr=alt.expr.if_(alt.datum.value > 1e5, alt.datum.value / 1e6 + 'M', alt.datum.value))).title(name),
         tooltip=tooltip,
     )
 
@@ -1101,7 +1107,7 @@ def _plot_ballistic(
 
     color = (
         alt.Color("dev_lag:Q")
-        .scale(range=MANAGUA_VALS)
+        .scale(scheme="blueorange")
         .legend(title="Development Lag (months)")
     )
     color_none = color.legend(None)
@@ -1230,7 +1236,7 @@ def _plot_broom(
 
     color = (
         alt.Color("dev_lag:Q")
-        .scale(range=MANAGUA_VALS)
+        .scale(scheme="blueorange")
         .legend(title="Development Lag (months)")
     )
     color_none = color.legend(None)
@@ -1363,7 +1369,7 @@ def _plot_drip(
 
     color = (
         alt.Color("dev_lag:Q")
-        .scale(range=MANAGUA_VALS)
+        .scale(scheme="blueorange")
         .legend(title="Development Lag (months)")
     )
     color_none = color.legend(None)
@@ -1486,7 +1492,7 @@ def _plot_histogram(
         alt.Chart(metric_data, title=title)
         .mark_bar()
         .encode(
-            x=alt.X(f"{name}:Q").bin({"maxbins": 50}).title(name),
+            x=alt.X(f"{name}:Q", axis=alt.Axis(labelExpr=alt.expr.if_(alt.datum.value > 1e5, alt.datum.value / 1e6 + "M", alt.datum.value))).bin({"maxbins": 50}).title(name),
             y=alt.Y("count()").title("Count"),
         )
     )
@@ -1620,39 +1626,6 @@ def _determine_facet_cols(n: int):
     return int(min(n, np.ceil(n / np.sqrt(n))))
 
 
-_MANAGUA_RAW = [
-    [1, 0.81263, 0.40424],
-    [0.92706, 0.69585, 0.36536],
-    [0.85597, 0.58963, 0.32987],
-    [0.78516, 0.4928, 0.29757],
-    [0.71247, 0.40508, 0.26891],
-    [0.633, 0.32425, 0.24442],
-    [0.54243, 0.24891, 0.22689],
-    [0.44962, 0.18873, 0.22534],
-    [0.37143, 0.15932, 0.25403],
-    [0.32066, 0.17283, 0.32465],
-    [0.29878, 0.22656, 0.42904],
-    [0.3009, 0.30548, 0.54191],
-    [0.32092, 0.39385, 0.64188],
-    [0.35064, 0.48323, 0.72305],
-    [0.38579, 0.57766, 0.79429],
-    [0.4241, 0.67996, 0.86256],
-    [0.46377, 0.78936, 0.93036],
-    [0.50411, 0.90708, 0.99978],
-]
-
-
-def _float_to_rgb(color_float: tuple[float, float, float]) -> str:
-    rf, gf, bf = color_float
-    r = round(rf * 255)
-    g = round(gf * 255)
-    b = round(bf * 255)
-    return f"#{r:02x}{g:02x}{b:02x}"
-
-
-MANAGUA_VALS = [_float_to_rgb(val) for val in _MANAGUA_RAW]
-
-
 def _slice_label(slice_tri: Triangle, base_tri: Triangle):
     slice_metadata = metadata_diff(base_tri.common_metadata, slice_tri.common_metadata)
 
